# Kosmorrolib - a library to compute your ephemerides!

[![Coverage Status](https://coveralls.io/repos/github/Kosmorro/lib/badge.svg?branch=main)](https://coveralls.io/github/Kosmorro/lib?branch=main) [![Version on PyPI](https://img.shields.io/pypi/v/kosmorrolib)](https://pypi.org/project/kosmorrolib)  [![IRC: #kosmorro on Libera.Chat](https://img.shields.io/badge/Libera.Chat-%23kosmorro-blueviolet)](https://web.libera.chat/?nick=Astronaut?#kosmorro)

## Installation

### Requirements

Kosmorrolib requires the following software to work:

- Python ≥ 3.7.0

And that's all!

### Production environment

Kosmorrolib is available [on PyPI](https://pypi.org/project/kosmorrolib/). To use it, invoke `pip install kosmorrolib`.

### Development environment

To contribute to Kosmorrolib, you will need [Poetry](https://python-poetry.org), a software to manage the project from development to publishing.

Clone this repository and run `poetry install` to install the dependencies.
And that's all, your development environment is ready for the fight! 👏

## Documentation

All the documentation can be found [on the website](https://kosmorro.space/lib/doc).
